package com.sky.mapper;

import com.github.pagehelper.Page;
import com.sky.annotation.AutoFill;
import com.sky.dto.EmployeePageQueryDTO;
import com.sky.entity.Employee;
import com.sky.enumeration.OperationType;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Select;

import java.util.List;

@Mapper
public interface EmployeeMapper {

    /**
     * 根据用户名查询员工
     *
     * @param username
     * @return
     */
    @Select("select * from t_expert where username = #{username}")
    Employee getByUsername(String username);


    /**
     * 插入员工数据
     *
     * @param employee
     */
    @Select("insert into employee (name, username, password, phone, " +
            "sex, id_number, create_time, update_time, create_user, update_user, status)" +
            "values" +
            "(#{name},#{username},#{password},#{phone},#{sex},#{idNumber},#{createTime},#{updateTime},#{createUser}," +
            "#{updateUser},#{status})")
    @AutoFill(value = OperationType.INSERT)
    void insert(Employee employee);

    /**
     * 分页查询
     *
     * @param employeePageQueryDTO
     * @return
     */
    Page<Employee> pageQuery(EmployeePageQueryDTO employeePageQueryDTO);

    /**
     * 根据主键动态修改属性
     *
     * @param employee
     */
    @AutoFill(value = OperationType.UPDATE)
    void update(Employee employee);

    /**
     * 根据id查询员工
     *
     * @param id
     * @return
     */
    @Select("select * from employee where id = #{id}")
    Employee getById(Integer id);

    @Select("SELECT * FROM t_loc64 WHERE SQRT( POW(PI() * 12656 * COS((#{volatitude} + lat) * PI() / 360) * (#{volongitude} - lng) / 180, 2) + POW(PI() * 12656 * ((#{volatitude} - lat) / 180), 2) ) < 100 limit 3")
    List<Employee> getLocation(double volatitude, double volongitude);
}
